@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 import re
-from calculate.lib.format.procmail import procmail
+from .procmail import procmail
 
 
 class openrc(procmail):
